@@ -15,8 +15,17 @@ class Parser(bs4.BeautifulSoup, ABC):
     def __init__(self, markup, features="lxml", **kw):
         super().__init__(markup, features, **kw)
 
-    def save_file(self):
-        util.save_to_file(self)
+    def save_file(self, file_path=None):
+        """
+        saves current html as file on <file_path> or, if file_path
+        is ommitted, it generates a distinctive name based on the url
+        Args:
+            file_path: optional string
+
+        Returns:
+
+        """
+        util.save_to_file(self, self.url)
 
     def generate_filename(self):
         return util.filename_from_url(self.url)
